@@ -21,8 +21,9 @@ int main(int argc, char *argv[])
 	QApplication app(argc, argv);
 
 	KLocalizedString::setApplicationDomain("kiriki");
-	KAboutData about("kiriki", i18n("Kiriki"), "0.3.0", i18n("A Yahtzee dice game for KDE"), KAboutLicense::GPL, i18n("© 2005-2007 Albert Astals Cid"), "http://games.kde.org/kiriki" );
-	about.addAuthor(i18n("Albert Astals Cid"), QString(), "aacid@kde.org");
+	KAboutData about(QStringLiteral("kiriki"), i18n("Kiriki"), QStringLiteral("0.3.0"), i18n("A Yahtzee dice game for KDE"), KAboutLicense::GPL, i18n("© 2005-2007 Albert Astals Cid"));
+	about.addAuthor(i18n("Albert Astals Cid"), QString(), QStringLiteral("aacid@kde.org"));
+	about.setHomepage(QStringLiteral("http://games.kde.org/kiriki"));
 	QCommandLineParser parser;
 	KAboutData::setApplicationData(about);
 	parser.addVersionOption();
